@@ -39,10 +39,18 @@ def parse(data):
         ...
     ValueError: fractional time may only apply to last component
     
+    >>> parse(datetime.date(2011,1,1))
+    datetime.datetime(2011, 1, 1, 0, 0)
+    
+    >>> parse(datetime.datetime(2011, 1, 2, 3, 4, 5))
+    datetime.datetime(2011, 1, 2, 3, 4, 5)
+    
     """
     
-    if isinstance(data, (datetime.datetime, datetime.date)):
+    if isinstance(data, datetime.datetime):
         return data
+    if isinstance(data, datetime.date):
+        return datetime.datetime.combine(data, datetime.time(0))
     
     if 'T' not in data:
         data = data.replace(' ', 'T')
